@@ -1,4 +1,4 @@
-# Copyright (C) 2007-2021 by the Free Software Foundation, Inc.
+# Copyright (C) 2007-2023 by the Free Software Foundation, Inc.
 #
 # This file is part of GNU Mailman.
 #
@@ -89,14 +89,15 @@ def send_welcome_message(mlist, member, language, text=''):
         list_name=mlist.display_name,
         list_requests=mlist.request_address,
         ))
-    digmode = (''                                   # noqa: F841
-               if member.delivery_mode is DeliveryMode.regular
-               else _(' (Digest mode)'))
-    msg = UserNotification(
-        formataddr((display_name, member.address.email)),
-        mlist.request_address,
-        _('Welcome to the "$mlist.display_name" mailing list${digmode}'),
-        text, language)
+    with _.using(language.code):
+        digmode = (''                                   # noqa: F841
+                   if member.delivery_mode is DeliveryMode.regular
+                   else _(' (Digest mode)'))
+        msg = UserNotification(
+            formataddr((display_name, member.address.email)),
+            mlist.request_address,
+            _('Welcome to the "${mlist.display_name}" mailing list${digmode}'),
+            text, language)
     msg['X-No-Archive'] = 'yes'
     msg.send(mlist, verp=as_boolean(config.mta.verp_personalized_deliveries))
 
@@ -116,12 +117,21 @@ def send_goodbye_message(mlist, address, language):
     :type language: ILanguage
     """
     goodbye_message = wrap(expand(getUtility(ITemplateLoader).get(
-        'list:user:notice:goodbye', mlist, language=language.code)))
-    msg = UserNotification(
-        address, mlist.bounces_address,
-        _('You have been unsubscribed from the $mlist.display_name '
-          'mailing list'),
-        goodbye_message, language)
+        'list:user:notice:goodbye', mlist, language=language.code),
+        mlist, dict(
+        user_email=address,
+        # For backward compatibility.
+        user_address=address,
+        fqdn_listname=mlist.fqdn_listname,
+        list_name=mlist.display_name,
+        list_requests=mlist.request_address,
+        )))
+    with _.using(language.code):
+        msg = UserNotification(
+            address, mlist.bounces_address,
+            _('You have been unsubscribed from the ${mlist.display_name} '
+              'mailing list'),
+            goodbye_message, language)
     msg.send(mlist, verp=as_boolean(config.mta.verp_personalized_deliveries))
 
 
@@ -137,7 +147,7 @@ def send_admin_subscription_notice(mlist, address, display_name):
     :type display_name: string
     """
     with _.using(mlist.preferred_language.code):
-        subject = _('$mlist.display_name subscription notification')
+        subject = _('${mlist.display_name} subscription notification')
     text = expand(
         getUtility(ITemplateLoader).get('list:admin:notice:subscribe', mlist),
         mlist, dict(
@@ -161,7 +171,8 @@ def send_admin_disable_notice(mlist, event, display_name):
     member = formataddr((display_name, event.email))
     data = {'member': member}
     with _.using(mlist.preferred_language.code):
-        subject = _('$member\'s subscription disabled on $mlist.display_name')
+        subject = _(
+            '${member}\'s subscription disabled on ${mlist.display_name}')
     text = expand(
         getUtility(ITemplateLoader).get('list:admin:notice:disable', mlist),
         mlist, data)
@@ -189,7 +200,7 @@ def send_admin_increment_notice(mlist, event, display_name):
     data = {'member': member}
     with _.using(mlist.preferred_language.code):
         subject = _(
-            '$member\'s bounce score incremented on $mlist.display_name')
+            '${member}\'s bounce score incremented on ${mlist.display_name}')
     text = expand(
         getUtility(ITemplateLoader).get('list:admin:notice:increment', mlist),
         mlist, data)
@@ -215,7 +226,7 @@ def send_admin_removal_notice(mlist, address, display_name):
     member = formataddr((display_name, address))
     data = {'member': member, 'mlist': mlist.display_name}
     with _.using(mlist.preferred_language.code):
-        subject = _('$member unsubscribed from ${mlist.display_name} '
+        subject = _('${member} unsubscribed from ${mlist.display_name} '
                     'mailing list due to bounces')
     text = expand(
         getUtility(ITemplateLoader).get('list:admin:notice:removal', mlist),
